# Copyright 2021 IBM All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
 This package provides a client library for accessing the IBM App Configuration.
"""
from ibm_appconfiguration.appconfiguration import AppConfiguration, Feature, \
    Property
from ibm_appconfiguration.configurations.models.configuration_type import ConfigurationType
from .version import __version__
